@@ -30,8 +30,6 @@ _current_path = _os.path.dirname(_os.path.abspath(__file__))
 
 _this_module = _sys.modules[__name__]
 
-print(package_name)
-
 _js_dist = [
     {
         'relative_package_path':
@@ -42,12 +40,12 @@ _js_dist = [
         'namespace':
         package_name
     },
-    #{
-    #    'relative_package_path': 'dash_mp_components.min.js.map',
-    #    'external_url': 'https://unpkg.com/{0}@{2}/{1}/{1}.min.js.map'.format(
-    #        package_name, __name__, __version__),
-    #    'namespace': package_name
-    # }
+    {
+        'relative_package_path': 'dash_mp_components.min.js.map',
+        'external_url': 'https://unpkg.com/{0}@{2}/{1}/{1}.min.js.map'.format(
+            package_name, __name__, __version__),
+        'namespace': package_name
+    }
 ]
 
 _css_dist = []
